@@ -1,11 +1,13 @@
 <?php
 
-$autoloader = require_once dirname(__DIR__).'/vendor/autoload.php';
-$autoloader->add('Swift_', __DIR__.'/unit');
+require_once dirname(__DIR__).'/vendor/autoload.php';
+
+// Disable garbage collector to prevent segfaults
+gc_disable();
 
 set_include_path(get_include_path().PATH_SEPARATOR.dirname(__DIR__).'/lib');
 
-\Mockery::getConfiguration()->allowMockingNonExistentMethods(false);
+Mockery::getConfiguration()->allowMockingNonExistentMethods(false);
 
 if (is_file(__DIR__.'/acceptance.conf.php')) {
     require_once __DIR__.'/acceptance.conf.php';
