@@ -517,9 +517,4 @@ class Swift_Transport_FailoverTransportTest extends \SwiftMailerTestCase
     {
         return $this->getMockery('Swift_Events_EventListener');
     }
-
-    private function _createInnerTransport()
-    {
-        return $this->getMockery('Swift_Transport');
-    }
 }
